//********************************************************************
//*-------------------------------------------------------------------
//* Sample Source
//*
//* 5724-A18
//*
//* (c) Copyright IBM Corp. 2000, 2002
//*
//* The source code for this program is not published or otherwise
//* divested of its trade secrets, irrespective of what has been
//* deposited with the US Copyright Office.
//*-------------------------------------------------------------------
//*
////////////////////////////////////////////////////////////////////////////////

import com.ibm.commerce.messaging.commands.*;

import java.lang.reflect.*;
import javax.naming.*;
import com.ibm.commerce.messaging.outboundservice.*;
import com.ibm.commerce.messaging.objects.*;

import com.ibm.commerce.command.*;
import com.ibm.commerce.exception.*;
import com.ibm.commerce.order.objects.*;
import com.ibm.commerce.ras.*;
import com.ibm.commerce.server.*;
import com.ibm.commerce.datatype.*;
import com.ibm.commerce.inventory.commands.*;
import java.math.*;
import java.rmi.*;
import java.util.*;
import javax.ejb.*;

/**
 * Sends an E-mail notification message for order release shipment. 
 */
public class ReleaseShipNotifyCmdImpl extends com.ibm.commerce.command.TaskCommandImpl implements ReleaseShipNotifyCmd {
	private java.lang.Long inOrderRn = null;
	private java.lang.Integer inOrderReleaseNum = null;
	

	public  static final String COPYRIGHT			= com.ibm.commerce.copyright.IBMCopyright.SHORT_COPYRIGHT;
	private static final String CLASS_NAME			= "com.ibm.commerce.messaging.commands.ReleaseShipNotifyCmdImpl";
	private static final String CHECK_PARAMETERS	= "checkParameters";
	private static final String istrPerformFunc		= "performExecute";
	private static final String istrBuildMessageSubjectFunc = "buildMessageSubject";

	private static final String SUBJECT             = "subject";
	private static final String SUBJECT_KEY         = "subject_key";

	private Vector          ivRecipients             = null;
	private Object  []      iMessageSubjectParamArray = null;
	private OrderAccessBean oaBean                 = null;
	private static Integer msg_type = new Integer(220);

/**
 * ReleaseShipNotifyCmdImpl constructor 
 */
public ReleaseShipNotifyCmdImpl() {
	super();
}
/**
 * Builds the subject for the notification message and returns it.
 * @return java.lang.String
 */
private String buildMessageSubject(String astrSubjectMessageKey)
{
	ECTrace.entry(ECTraceIdentifiers.COMPONENT_ORDER, CLASS_NAME, istrBuildMessageSubjectFunc);
	
	ECMessage subjectMsg = new ECMessage(ECMessageSeverity.INFO, ECMessageType.USER, astrSubjectMessageKey);
	String strSubject    = ECMessageHelper.getUserMessage(subjectMsg, getMessageSubjectParms(), getCommandContext().getLocale());
		
	ECTrace.exit(ECTraceIdentifiers.COMPONENT_ORDER, CLASS_NAME, istrBuildMessageSubjectFunc);
		
	return strSubject;
}
/**
 * Returns the parameters for notification message subject.
 * @return java.lang.Object[] 
 */
public java.lang.Object[] getMessageSubjectParms() {
	return iMessageSubjectParamArray;
}
/**
 * Returns the Message Type Id
 * @return java.lang.Integer 
 */
public Integer getMessageType() throws RemoteException, CreateException, NamingException, FinderException
	{
		
			/***
			MsgTypesAccessBean bean = new MsgTypesAccessBean();
			Enumeration beanList = bean.findByMsgTName("ReleaseShipNotify");

			if ( (beanList != null) && beanList.hasMoreElements() )
			{
				MsgTypesAccessBean aBean = (MsgTypesAccessBean)beanList.nextElement();
		    	return aBean.getMsgtype_id();
			}
			else
			return null;**/
			return msg_type;
		
	}
/**
 * Returns the order access bean.
 * @return com.ibm.commerce.order.objects.OrderAccessBean 
 */	
private OrderAccessBean getOrderBean() { return oaBean;}
/**
 * Returns the order release number.
 * @return java.lang.Integer 
 */
public java.lang.Integer getOrderReleaseNum() 
{
	return inOrderReleaseNum;
}
/**
 * Returns the order reference number.
 * @return java.lang.Long 
 */
public java.lang.Long getOrderRn() 
{
	return inOrderRn;
}
/**
 * Returns the list of recipients for the notification message.
 * @return java.util.Vector 
 */
public java.util.Vector getRecipients() {
	return ivRecipients;
}
/**
 * This is the real function part of the ReleaseShipNotify command - sends a
 * notification message.
 */
public void performExecute() throws ECException
{
	ECTrace.entry(ECTraceIdentifiers.COMPONENT_MESSAGING, CLASS_NAME, istrPerformFunc);
	
	try
	{		
		if (getMessageType () == null)
				throw new ECApplicationException(new ECMessage(ECMessageKey._API_CANT_FIND_IN_ENV), this.getClass().getName(), istrPerformFunc, "notification template id");
			
			Messaging ms = new Messaging(getMessageType(), getOrderBean().getStoreEntityIdInEJBType()); // getStoreId());

			TypedProperty NVPs = new TypedProperty();			
			NVPs.put(ECConstants.EC_ORDER_RN, getOrderRn());
			NVPs.put(InventoryConstants.ORDRELEASE_NUM, getOrderReleaseNum());

			CommandContext cmdContextClone = (CommandContext)getCommandContext().clone();

			Long originalCommandContextUserId = cmdContextClone.getUserId();
			Integer originalCommandContextStoreId = cmdContextClone.getStoreId();
			
			// ******** IMPORTANT
			cmdContextClone.setStoreId(getOrderBean().getStoreEntityIdInEJBType());
			// ********

			cmdContextClone.setUserId(getOrderBean().getMemberIdInEJBType());
			cmdContextClone.setStore(getCommandContext().getStore(getOrderBean().getStoreEntityIdInEJBType()));

			// ********  IMPORTANT
			cmdContextClone.setStoreCommand(true);
			// *********

			
			//NVPs.put("ManifestNum", getManifestRn());
			ms.compose(null, cmdContextClone, NVPs);
			 
			
			String strMsgSubject = ms.getUserData(null, SUBJECT);
			if (null == strMsgSubject || strMsgSubject.length() == 0)
			{   // subject is usually not specified in the db when it needs to be parameterized;
				// then it is stored in the user resource bundle and parameters are provided
				// by the caller of this task command (through setMessageSubjectParms()).
				// The key to the message in the resource bundle is located in the ISEDITATT
				// database table for a given message type
				
				String strMsgSubjectKey = ms.getUserData(null, SUBJECT_KEY);

				
				if (strMsgSubjectKey!=null)
				  ms.setConfigData(SUBJECT, buildMessageSubject(strMsgSubjectKey));
			}
			
		   
			Enumeration enRecipients = null;
			if (getRecipients()!=null)
			  sendNotification(ms, getRecipients().elements()); // send notification to all of the recipients
			else
			  sendNotification(ms);  // send notification to the current shopper


			 // set the user id back!!! (command context cloning problem)
			cmdContextClone.setUserId(originalCommandContextUserId);
			cmdContextClone.setStoreId(originalCommandContextStoreId);
		
	}
	catch (ECSystemException e)
	{ // this is not a fatal error; we will not roll back if order notification failed
	  // the exact error should have been reported by the messaging system
	  ECTrace.trace(ECTraceIdentifiers.COMPONENT_MESSAGING, CLASS_NAME, istrPerformFunc, "Failed sending Release Ship Notification message");	
	}
	catch (RemoteException e)
	{
		throw new ECSystemException(
						ECMessage._ERR_REMOTE_EXCEPTION, this.getClass().getName(), istrPerformFunc,
						ECMessageHelper.generateMsgParms( e.getMessage()), e );
	}
	catch (CreateException e)
	{
		throw new ECSystemException(
						ECMessage._ERR_CREATE_EXCEPTION, this.getClass().getName(), istrPerformFunc,
						ECMessageHelper.generateMsgParms( e.getMessage()), e );
	}
	catch (NamingException e)
	{
		throw new ECSystemException(
						ECMessage._ERR_GENERIC, this.getClass().getName(), istrPerformFunc,
						ECMessageHelper.generateMsgParms( e.getMessage()), e );
	}
	catch (FinderException e)
	{
		throw new ECSystemException(
						ECMessage._ERR_FINDER_EXCEPTION, this.getClass().getName(), istrPerformFunc,
						ECMessageHelper.generateMsgParms( e.getMessage()), e );
	}
	

	ECTrace.exit(ECTraceIdentifiers.COMPONENT_MESSAGING, CLASS_NAME, istrPerformFunc);
}
/**
 * Sends the notification message  to the current user.
 * @param message com.ibm.commerce.messaging.outboundservice.Messaging 
 */
private void sendNotification(Messaging anMs) throws ECSystemException, NamingException, FinderException, CreateException, RemoteException // throws NoSuchMethodException,  InvocationTargetException, InstantiationException, ClassNotFoundException, IllegalAccessException, ECSystemException
{
	
	anMs.addMember(getOrderBean().getMemberIdInEJBType());
	// change : use sendTransact() here
	// anMs.sendImmediate();
	anMs.sendTransacted();
}
/**
 * Sends the notification message  to all the recipients set by the caller of the task command.
 * @param message com.ibm.commerce.messaging.outboundservice.Messaging
 * @param recipients java.util.Enumeration 
 */
private void sendNotification(Messaging anMs, Enumeration anenRecipients) throws ECSystemException  //throws NoSuchMethodException,  InvocationTargetException, InstantiationException, ClassNotFoundException, IllegalAccessException, ECSystemException
{ 
	while (anenRecipients.hasMoreElements())
	{
		anMs.setConfigData("recipient", (String) anenRecipients.nextElement());
		// ms.sendTransact();
		// anMs.sendImmediate();
		anMs.sendTransacted();
	}
}
/**
 * Sets the parameters for notification message subject.
 * @param messageSubjectParams java.lang.Object[] 
 */
public void setMessageSubjectParms(java.lang.Object[] newMessageSubjectParms) {
	iMessageSubjectParamArray = newMessageSubjectParms;
}
/**
 * Sets the order release number.
 * @param java.lang.Integer 
 */
public void setOrderReleaseNum(Integer anOrderReleaseNum) 
{
	inOrderReleaseNum = anOrderReleaseNum;	
}
/**
 * Sets the order reference number.
 * @param java.lang.Long 
 */
public void setOrderRn(Long anOrderRn) 
{

	inOrderRn = anOrderRn;

	if ( anOrderRn != null)
	{
		oaBean = new OrderAccessBean();
		oaBean.setInitKey_orderId(anOrderRn.toString() );
	}
}
/**
 * Sets the list of recipients for the notification message.
 * @param recipients java.util.Vector 
 */
public void setRecipients(java.util.Vector newRecipients) {
	ivRecipients = newRecipients;
}
}
