//********************************************************************
//*-------------------------------------------------------------------
//* Sample Source
//*
//* 5724-A18
//*
//* (c) Copyright IBM Corp. 2000, 2002
//*
//* The source code for this program is not published or otherwise
//* divested of its trade secrets, irrespective of what has been
//* deposited with the US Copyright Office.
//*-------------------------------------------------------------------
//*
////////////////////////////////////////////////////////////////////////////////

import com.ibm.commerce.messaging.commands.*;

import java.util.*;
import java.text.*;
import java.rmi.*;
import javax.ejb.*;
import javax.naming.*;
import java.lang.reflect.*;

import com.ibm.commerce.base.objects.*;
import com.ibm.commerce.catalog.objects.*;
import com.ibm.commerce.fulfillment.objects.*;
import com.ibm.commerce.user.objects.*;
import com.ibm.commerce.common.objects.*;
import com.ibm.commerce.order.objects.*;

import com.ibm.commerce.ras.*;
import com.ibm.commerce.exception.*;
import com.ibm.commerce.command.*;
import com.ibm.commerce.server.*;
import com.ibm.commerce.messaging.*;
import com.ibm.commerce.messaging.util.*;
import com.ibm.commerce.messaging.outboundservice.*;
import com.ibm.commerce.datatype.*;
/**
 * Task command to create and send legacy WCS Order Create message
 */
public class SendWCSOrderCmdImpl  extends TaskCommandImpl implements com.ibm.commerce.order.commands.OrderMessagingCmd
{
	/**
	 * The internal copyright field.
	 */	
	public static final String COPYRIGHT = com.ibm.commerce.copyright.IBMCopyright.SHORT_COPYRIGHT;
	private Long orderRefNumber = null;
	private String storeID = null;
	private String orderMsg = null;
	private static String spaces;
	private static String zeroes;
/**
 * Used to hold temporary name value pairs for order information
 * retrieved from database which will be used when building the message
 */
public com.ibm.commerce.datatype.TypedProperty orderNVP = null;
	private	com.ibm.commerce.user.objects.AddressAccessBean addressBean	= new com.ibm.commerce.user.objects.AddressAccessBean();

	private java.util.Enumeration set = null;


/**
 * Used to provide data as input parms to doPreProcess() 
 * and doPostProcess()
 */
protected TypedProperty ocProp = null;

/**
* Message type for WCS Order Create message = 100
*/		
public final static Integer MSGTYPE = new Integer("100");
/**
 * Performs a additional processing after the command executes.
 * @return boolean
 * @param aRequestProperty com.ibm.commerce.datatype.TypedProperty
 * @exception ECException
 */
public boolean doPostProcess(TypedProperty aRequestProperty) {
	return true;
}
/**
 * Performs additional processing before the command executes.
 * @return boolean
 * @param aRequestProperty com.ibm.commerce.datatype.TypedProperty
 * @exception ECException
 */
public boolean doPreProcess(TypedProperty aRequestProperty) {
	return true;
}
/**
 * Get the order information, build the order create message and the message
 * @return boolean
 * @param aRequestProperty com.ibm.commerce.datatype.TypedProperty
 */
public boolean doProcess() 
{
	// If successfully collected Order Create information
	if (setOrderNVPValues())
	{
		// Build the order create message
		if (writeOrder())
		{
			// Send the message out using send transacted send mode
			// provided by the messaging subsystem
			if (!(sendMessage()))
				return false; 	// do Process failed during sendMessage()
		}			
		else
			return false; 		// do Process failed during writeOrder()
	}
	else
		return false;			// do Process failed during setOrderNVPValues()

	return true;
}
/**
 * Converts timestamp string to YYYYMMDD format
 * @return java.lang.String
 * @param str java.lang.String - timestamp
 */
public String getDate(String str) 
{
	String input = str.trim();
	String output = input.substring(0,4);
	output += input.substring(5,7);
	output += input.substring(8,10);
	return output;
}
/**
 * Get field.
 * Creation date: (6/6/00 6:38:13 PM)
 * @return java.lang.String
 * @param tp com.ibm.commerce.datatype.TypedProperty
 * @param name java.lang.String
 * @param length int
 */
private String getField(TypedProperty tp, String name, int length) throws Exception 
{
	String nullString = "";
	try {
	String fieldString;

	if ((fieldString=tp.getString(name,null)) == null)
		return pad(nullString,length);
	else
		return pad(fieldString,length);
}
catch (Exception ex)
{
	// Parameter not found, return null string
	return nullString;
}	

}
/**
 * Implement this method when you extend the command to
 * do outbound message extension at order header level using the 
 * USRLST record.
 * It should return a String object that contains a series
 * of DATUSR records.
 */
public String getHeaderExtensionRecords() {
	return null;
}
/**
 * Implement this method when you extend the command to
 * do outbound message extension at order item level using 
 * the USRLST record.
 * It should return a String object that contains a series
 * of DATUSR records.
 */
public String getItemExtensionRecords() {
	return null;
}
/**
 * Get the order create message content built by the command
 * @return java.lang.String
 */
public java.lang.String getOrderMsg() {
	return orderMsg;
}
/**
 * Get the order reference number passed to this command
 * @return java.lang.Long
 */
public Long getOrderRn() {
	return orderRefNumber;
}
/**
 * Converts timestamp string to HHMMSS format
 * @return java.lang.String
 * @param str java.lang.String - timestamp
 */
public String getTime(String str)
{
	String input = str.trim();
	String output = input.substring(11,13);
	output += input.substring(14,16);
	output += input.substring(17,19);
	return output;
}
/**
 * This method checks if command is ready to be executed
 */
public boolean isReadyToCallExecute()
	{
		ECTrace.entry(ECTraceIdentifiers.COMPONENT_TRANSPORT_ADAPTER, this.getClass().getName(), "isReadyToCallExecute");
		if (!super.isReadyToCallExecute())
			return false;

		if (orderRefNumber == null) {
			ECMessageLog.out(ECMessage._ERR_DIDNT_SET_ORDER, this.getClass().getName(), "isReadyToCallExecute");
			return false;
		}

		ECTrace.exit(ECTraceIdentifiers.COMPONENT_TRANSPORT_ADAPTER, this.getClass().getName(), "isReadyToCallExecute");
		return true;
	}
/**
 * Pad.
 * Creation date: (6/5/00 3:02:23 PM)
 * @return java.lang.String
 * @param inString java.lang.String
 * @param outputLength int

 */
private String pad(String inString, int outputLength) {

	return pad(inString, outputLength, true, true);
}
/**
 * Pad.
 * Creation date: (6/5/00 3:02:23 PM)
 * @return java.lang.String
 * @param inString java.lang.String
 * @param outputLength int
 * @param spaces_fl boolean
 * @param append_fl boolean
 */
private String pad(String inString, int outputLength, boolean spaces_fl, boolean append_fl) {
	//Pads inString with spaces or zeroes to the outputLength in length, appending to inString if
	//append_fl is on, or prepending if append_fl is off
	//If outputLength < length of inString, return inString as passed
	String resultString;
	int inputLength = inString.length();
	int padLength = outputLength - inputLength;
	if (padLength <=0) resultString = inString;
	else {
		String padString;
		spaces = new String(" ");
		zeroes = new String("0");
		if (spaces_fl) padString = spaces;
		else padString = zeroes;
		if (padLength > padString.length()) {	//if static pad arrays are inadequate, dynamically
												//prepare your own
			String tempPadString=new String();
			while (tempPadString.length() < padLength)
				tempPadString += padString;
			padString = tempPadString;
		}
		if (append_fl) resultString = inString + padString.substring(0,padLength);
		else resultString = padString.substring(0,padLength) + inString;
	}
	return resultString;
}
	private static void padArray() {
		for (int i=0; i<50; i++)
		{
			spaces += "          ";  //10 spaces x 50 iterations = String of 500 spaces
			zeroes += "0000000000";  //10 zeroes x 50 iterations = String of 500 zeroes
			//500 should be enough since the fields in NC order create are no more than 254
		}
	}
/**
 * Execute the command by calling doPreProcess, doProcess and doPostProcess
 */
public void performExecute() throws ECException {
	super.performExecute();
	final String methodName = "performExecute";

	ECTrace.entry(ECTraceIdentifiers.COMPONENT_TRANSPORT_ADAPTER, this.getClass().getName(), "performExecute");
	orderNVP = new TypedProperty();
	if (!doPreProcess(ocProp))
	{
		ECMessageLog.out(ECMessage._ERR_DO_PRE_PROCESS, this.getClass().getName(), methodName);
	}
	else if (!doProcess())
	{
		ECMessageLog.out(ECMessage._ERR_DO_PROCESS, this.getClass().getName(), methodName);
	}
	else if (!doPostProcess(ocProp))
	{
		ECMessageLog.out(ECMessage._ERR_DO_POST_PROCESS, this.getClass().getName(), methodName);
	}

	ECTrace.exit(ECTraceIdentifiers.COMPONENT_TRANSPORT_ADAPTER, this.getClass().getName(), "performExecute");
}
/**
 * Send the outbound order create message by doing the following
 * - Set the content of the message
 * - Send the message using outbound messaging system sendTransacted() service
 * @return boolean
 */
public boolean sendMessage()    
{
	final String methodName = "sendMessage";
 	try
 	{
	 	String orderStoreID = orderNVP.getString(OrderCreateConstants.ORDER_STORE_ID);
	
		// Instantiate the Messaging System object 
		Messaging ms = new Messaging(MSGTYPE, new Integer(orderStoreID));

	 	// Set the message to be send
 		ms.setContent(null,null,getOrderMsg().getBytes("UTF8"));

		ms.sendTransacted();
 	}
	catch (Exception ex)
	{
		ECMessageLog.out(ECMessage._ERR_OC_SEND_ORDER_ERROR, this.getClass().getName(), methodName);
		return false;
	}
	return true;
}
/**
 * Get all the bill-to data for WCS Order Create message
 * @return boolean
 * 
 */
public boolean setOrderCreateBillToData() throws ECException {
final String methodName = "setOrderCreateBillToData";
// Get all the purchaser data for NC Order Create message from the appropriate tables
// BillTo Data <HDR030>
try 
{
	String billToRefNumber = orderNVP.getString(OrderCreateConstants.BILLTO_REF_NUMBER);
	if (billToRefNumber == OrderCreateConstants.NOT_AVAILABLE) return true;

	AddressAccessBean currAddressBean = new AddressAccessBean();
	currAddressBean.setInitKey_AddressId(billToRefNumber);
	
	String tempString;
	if ((tempString=currAddressBean.getLastName()) != null)
		orderNVP.put(OrderCreateConstants.BILLTO_LAST_NAME, tempString);
	if ((tempString=currAddressBean.getMiddleName()) != null)
		orderNVP.put(OrderCreateConstants.BILLTO_MIDDLE_NAME, tempString);
	if ((tempString=currAddressBean.getFirstName()) != null)
		orderNVP.put(OrderCreateConstants.BILLTO_FIRST_NAME, tempString);
	if ((tempString=currAddressBean.getAddress1()) != null)
		orderNVP.put(OrderCreateConstants.BILLTO_ADDR1, tempString);
	if ((tempString=currAddressBean.getAddress2()) != null)
		orderNVP.put(OrderCreateConstants.BILLTO_ADDR2, tempString);
	if ((tempString=currAddressBean.getAddress3()) != null)
		orderNVP.put(OrderCreateConstants.BILLTO_ADDR3, tempString);
	if ((tempString=currAddressBean.getCity()) != null)
		orderNVP.put(OrderCreateConstants.BILLTO_CITY, tempString);
	if ((tempString=currAddressBean.getState()) != null)
		orderNVP.put(OrderCreateConstants.BILLTO_STATE, tempString);
	if ((tempString=currAddressBean.getCountry()) != null)
		orderNVP.put(OrderCreateConstants.BILLTO_COUNTRY, tempString);
	if ((tempString=currAddressBean.getZipCode()) != null)
		orderNVP.put(OrderCreateConstants.BILLTO_ZIPCODE, tempString);
	if ((tempString=currAddressBean.getEmail1()) != null)
		orderNVP.put(OrderCreateConstants.BILLTO_EMAIL1, tempString);
	if ((tempString=currAddressBean.getEmail2()) != null)
		orderNVP.put(OrderCreateConstants.BILLTO_EMAIL2, tempString);
	if ((tempString=currAddressBean.getPhone1()) != null)
		orderNVP.put(OrderCreateConstants.BILLTO_PHONE1, tempString);
	if ((tempString=currAddressBean.getPhone2()) != null)
		orderNVP.put(OrderCreateConstants.BILLTO_PHONE2, tempString);
		
	if ((tempString=currAddressBean.getFax1()) != null)
		orderNVP.put(OrderCreateConstants.BILLTO_FAX, tempString);
	else if ((tempString=currAddressBean.getFax2()) != null)
		orderNVP.put(OrderCreateConstants.BILLTO_FAX, tempString);

	currAddressBean.commitCopyHelper();	
}
catch( javax.ejb.CreateException ex ) 
{
	throw new ECSystemException(ECMessage._ERR_CREATE_EXCEPTION, this.getClass().getName(), methodName,
			ECMessageHelper.generateMsgParms( ex.getMessage()), ex );
}
catch( javax.naming.NamingException ex ) {
	throw new ECSystemException(ECMessage._ERR_GENERIC, this.getClass().getName(), methodName, 
			ECMessageHelper.generateMsgParms(ex.getMessage()), ex );
}
catch( java.rmi.RemoteException ex ) {
	throw new ECSystemException(ECMessage._ERR_REMOTE_EXCEPTION, this.getClass().getName(), methodName, 
			ECMessageHelper.generateMsgParms(ex.getMessage()), ex );
}
catch (FinderException ex) {
	ECMessageLog.out(ECMessage._ERR_OC_BILLTO_ERROR, this.getClass().getName(), methodName);
	return false;
}

return true;
}
/**
 * Get all the order header values for WCS Order Create message
 * @return boolean
 * 
 */
public boolean setOrderCreateHeaderData() throws ECException {
final String methodName = "setOrderCreateHeaderData";
// Get all the order values for NC Order Create message from the appropriate tables
// Header Data <HDR010>
com.ibm.commerce.order.objects.OrderAccessBean orderBean = new com.ibm.commerce.order.objects.OrderAccessBean ();
orderBean.setInitKey_orderId(orderRefNumber.toString());

try 
{
	String tempString = null;

	if ((tempString=orderBean.getCurrency()) != null)
		orderNVP.put(OrderCreateConstants.CURRENCY_TYPE, tempString);
	if ((tempString=orderBean.getTotalProductPrice()) != null)
		orderNVP.put(OrderCreateConstants.TOTAL_PRICE, tempString);
	if ((tempString=orderBean.getTotalTax()) != null)
		orderNVP.put(OrderCreateConstants.TOTAL_TAX_PRICE, tempString);
	if ((tempString=orderBean.getTotalShippingCharge()) != null)
		orderNVP.put(OrderCreateConstants.TOTAL_SHIPPING_PRICE, tempString);
	if ((tempString=orderBean.getTotalShippingTax()) != null)
		orderNVP.put(OrderCreateConstants.TOTAL_TAX_SHIPPING_PRICE, tempString);

	if (orderBean.getMemberIdInEJBType() != null)
		orderNVP.put(OrderCreateConstants.SHOPPER_REF_NUMBER, orderBean.getMemberId());
	else
		orderNVP.put(OrderCreateConstants.SHOPPER_REF_NUMBER, OrderCreateConstants.NOT_AVAILABLE);
			
	if (orderBean.getStoreEntityIdInEJBType() != null)
	{
		storeID=orderBean.getStoreEntityId();
		orderNVP.put(OrderCreateConstants.MERCHANT_REF_NUMBER, storeID);
		orderNVP.put(OrderCreateConstants.ORDER_STORE_ID, storeID);
	}
	else
	{
		orderNVP.put(OrderCreateConstants.MERCHANT_REF_NUMBER, OrderCreateConstants.NOT_AVAILABLE);
		orderNVP.put(OrderCreateConstants.ORDER_STORE_ID, OrderCreateConstants.NOT_AVAILABLE);
	}
	
	if ((tempString=orderBean.getMerchantOrderId()) != null)
		orderNVP.put(OrderCreateConstants.MERCHANT_ORDER_NUMBER, tempString);
	
	if (orderBean.getAddressIdInEJBType() != null)
		orderNVP.put(OrderCreateConstants.BILLTO_REF_NUMBER, orderBean.getAddressId());
	else
		orderNVP.put(OrderCreateConstants.BILLTO_REF_NUMBER, OrderCreateConstants.NOT_AVAILABLE);
		
	if ((tempString=orderBean.getField1()) != null)
		orderNVP.put(OrderCreateConstants.ORDER_CUST_FIELD1, tempString);
	if ((tempString=orderBean.getField2()) != null)
		orderNVP.put(OrderCreateConstants.ORDER_CUST_FIELD2, tempString);
	if ((tempString=orderBean.getField3()) != null)
		orderNVP.put(OrderCreateConstants.ORDER_CUST_FIELD3, tempString);

	java.sql.Timestamp tempTimestamp = null;
	if ((tempTimestamp=orderBean.getPlaceOrderTimeInEJBType()) != null) 
	{
		tempString=orderBean.getPlaceOrderTime();

		java.lang.String tempDate = null;
		java.lang.String tempTime = null;
		tempDate = getDate(tempString);
		orderNVP.put(OrderCreateConstants.ORDER_DATE, tempDate);
		
		tempTime = getTime(tempString);
	    orderNVP.put(OrderCreateConstants.ORDER_TIME, tempTime);
	}
}
catch( javax.ejb.CreateException ex ) 
{
	throw new ECSystemException(ECMessage._ERR_CREATE_EXCEPTION, this.getClass().getName(), methodName,
			ECMessageHelper.generateMsgParms( ex.getMessage()), ex );
}
catch( javax.naming.NamingException ex ) {
	throw new ECSystemException(ECMessage._ERR_GENERIC, this.getClass().getName(), methodName, 
			ECMessageHelper.generateMsgParms(ex.getMessage()), ex );
}
catch( java.rmi.RemoteException ex ) {
	throw new ECSystemException(ECMessage._ERR_REMOTE_EXCEPTION, this.getClass().getName(), methodName, 
			ECMessageHelper.generateMsgParms(ex.getMessage()), ex );
}
catch (FinderException ex) {
	ECMessageLog.out(ECMessage._ERR_ORDER_NOT_FOUND, this.getClass().getName(), methodName, 
		orderRefNumber,OrderCreateConstants.ORDER_REF_NUMBER);
	return false;
}

return true;
}
/**
 * Get all the order header values for WCS Order Create message
 * @return boolean
 * 
 */
public boolean setOrderCreateItemData() throws ECException {
final String methodName = "setOrderCreateItemData";
try 
{
	Vector itemsVector = new Vector();
	java.util.Enumeration set;
	String tempString;
	int i = 0;

	com.ibm.commerce.order.objects.OrderItemAccessBean orderItemBean = new com.ibm.commerce.order.objects.OrderItemAccessBean();
	com.ibm.commerce.order.objects.OrderItemAccessBean currOrderItemBean = null;

	set = orderItemBean.findByOrder(orderRefNumber);

	if (!(set.hasMoreElements()))
	{
		ECMessageLog.out(ECMessage._ERR_LOAD_ORDERITEM_DATA, this.getClass().getName(), methodName); 
		return false;
	}
	
	while (set.hasMoreElements()) {
		currOrderItemBean = (com.ibm.commerce.order.objects.OrderItemAccessBean) set.nextElement();
		TypedProperty itemNVP = new TypedProperty();
		i++;
		itemNVP.put(OrderCreateConstants.ITEM_LINE_NUMBER,Integer.toString(i));
		if ((tempString=currOrderItemBean.getOrderItemId()) != null)
			itemNVP.put(OrderCreateConstants.ITEM_REF_NUMBER, tempString);
		if ((tempString=currOrderItemBean.getPrice()) != null)
			itemNVP.put(OrderCreateConstants.ITEM_UNIT_PRICE, tempString);
			
		if ((tempString=currOrderItemBean.getCurrency()) != null)
			itemNVP.put(OrderCreateConstants.ITEM_CURRENCY_TYPE, tempString);
		else if ((tempString=orderNVP.getString(OrderCreateConstants.ITEM_CURRENCY_TYPE)) != null)
			itemNVP.put(OrderCreateConstants.ITEM_CURRENCY_TYPE, tempString);
				
		if ((tempString=currOrderItemBean.getQuantity()) != null)
			itemNVP.put(OrderCreateConstants.ITEM_PRODUCT_QUANTITY, tempString);
		if ((tempString=currOrderItemBean.getStatus()) != null)
			itemNVP.put(OrderCreateConstants.ITEM_STATUS, tempString);
		if ((tempString=currOrderItemBean.getComment()) != null)
			itemNVP.put(OrderCreateConstants.ITEM_SHIPTO_COMMENT, tempString);
		if ((tempString=currOrderItemBean.getTimeCreated()) != null)
			itemNVP.put(OrderCreateConstants.ITEM_CREATION_TIMESTAMP, tempString);
		if ((tempString=currOrderItemBean.getLastUpdate()) != null)
			itemNVP.put(OrderCreateConstants.ITEM_UPDATE_TIMESTAMP, tempString);
		if ((tempString=currOrderItemBean.getField1()) != null)
			itemNVP.put(OrderCreateConstants.ITEM_CUST_FIELD1, tempString);
		if ((tempString=currOrderItemBean.getField2()) != null)
			itemNVP.put(OrderCreateConstants.ITEM_CUST_FIELD2, tempString);

		if ((tempString=currOrderItemBean.getShippingModeId()) != null)
			itemNVP.put(OrderCreateConstants.ITEM_SHIPMODE_REF_NUMBER, tempString);
		else if ((tempString=orderNVP.getString(OrderCreateConstants.DEFAULT_STORE_SHIPMODE)) != null)
			itemNVP.put(OrderCreateConstants.ITEM_SHIPMODE_REF_NUMBER, tempString);

		// If SHIPMODE is available then get the Shipping Carrier and Method
		if (tempString != null)
		{
			com.ibm.commerce.fulfillment.objects.ShippingModeAccessBean shipModeBean = new com.ibm.commerce.fulfillment.objects.ShippingModeAccessBean ();
			shipModeBean.setInitKey_shippingModeId(tempString);
			if ((tempString=shipModeBean.getCarrier()) != null)
				itemNVP.put(OrderCreateConstants.ITEM_SHIPPING_CARRIER, tempString);
			if ((tempString=shipModeBean.getCode()) != null)
				itemNVP.put(OrderCreateConstants.ITEM_SHIPPING_METHOD, tempString);
		}

		String catentry_id;
		if ((catentry_id=currOrderItemBean.getCatalogEntryId()) != null) {
			itemNVP.put(OrderCreateConstants.ITEM_PRODUCT_REF_NUMBER, catentry_id);

			com.ibm.commerce.catalog.objects.CatalogEntryAccessBean catEntryBean = new com.ibm.commerce.catalog.objects.CatalogEntryAccessBean ();
			catEntryBean.setInitKey_catalogEntryReferenceNumber(catentry_id);
			if ((tempString=catEntryBean.getPartNumber()) != null)
				itemNVP.put(OrderCreateConstants.ITEM_PRODUCT_NUMBER, tempString);
			com.ibm.commerce.catalog.objects.CatalogEntryDescriptionAccessBean catEntryDescBean = new com.ibm.commerce.catalog.objects.CatalogEntryDescriptionAccessBean ();
			catEntryDescBean.setInitKey_catalogEntryReferenceNumber(catentry_id);
			catEntryDescBean.setInitKey_language_id(getCommandContext().getLanguageId().toString());
			
			if ((tempString=catEntryDescBean.getShortDescription()) != null)
				itemNVP.put(OrderCreateConstants.ITEM_PRODUCT_SHORT_DESCRIPTION, tempString);
		}

		if ((tempString=currOrderItemBean.getAddressId()) != null) {
			itemNVP.put(OrderCreateConstants.ITEM_SHIPTO_ADDR_REF_NUMBER, tempString);

			AddressAccessBean currAddressBean = new AddressAccessBean();
			currAddressBean.setInitKey_AddressId(tempString);
			currAddressBean.refreshCopyHelper();

			if ((tempString=currAddressBean.getLastName()) != null)
				itemNVP.put(OrderCreateConstants.ITEM_SHIPTO_LAST_NAME, tempString);
			if ((tempString=currAddressBean.getMiddleName()) != null)
				itemNVP.put(OrderCreateConstants.ITEM_SHIPTO_MIDDLE_NAME, tempString);
			if ((tempString=currAddressBean.getFirstName()) != null)
				itemNVP.put(OrderCreateConstants.ITEM_SHIPTO_FIRST_NAME, tempString);
			if ((tempString=currAddressBean.getAddress1()) != null)
				itemNVP.put(OrderCreateConstants.ITEM_SHIPTO_ADDR1, tempString);
			if ((tempString=currAddressBean.getAddress2()) != null)
				itemNVP.put(OrderCreateConstants.ITEM_SHIPTO_ADDR2, tempString);
			if ((tempString=currAddressBean.getAddress3()) != null)
				itemNVP.put(OrderCreateConstants.ITEM_SHIPTO_ADDR3, tempString);
			if ((tempString=currAddressBean.getCity()) != null)
				itemNVP.put(OrderCreateConstants.ITEM_SHIPTO_CITY, tempString);
			if ((tempString=currAddressBean.getState()) != null)
				itemNVP.put(OrderCreateConstants.ITEM_SHIPTO_STATE, tempString);
			if ((tempString=currAddressBean.getCountry()) != null)
				itemNVP.put(OrderCreateConstants.ITEM_SHIPTO_COUNTRY, tempString);
			if ((tempString=currAddressBean.getZipCode()) != null)
				itemNVP.put(OrderCreateConstants.ITEM_SHIPTO_ZIPCODE, tempString);
			if ((tempString=currAddressBean.getEmail1()) != null)
				itemNVP.put(OrderCreateConstants.ITEM_SHIPTO_EMAIL1, tempString);
			if ((tempString=currAddressBean.getEmail2()) != null)
				itemNVP.put(OrderCreateConstants.ITEM_SHIPTO_EMAIL2, tempString);
			if ((tempString=currAddressBean.getPhone1()) != null)
				itemNVP.put(OrderCreateConstants.ITEM_SHIPTO_PHONE1, tempString);
			if ((tempString=currAddressBean.getPhone2()) != null)
				itemNVP.put(OrderCreateConstants.ITEM_SHIPTO_PHONE2, tempString);
			if ((tempString=currAddressBean.getFax1()) != null)
				itemNVP.put(OrderCreateConstants.ITEM_SHIPTO_FAX, tempString);
			else if ((tempString=currAddressBean.getFax2()) != null)
				itemNVP.put(OrderCreateConstants.ITEM_SHIPTO_FAX, tempString);
		}
	
			
		itemsVector.addElement(itemNVP);
	}
	orderNVP.put("ItemsVector",itemsVector);
}
catch( javax.ejb.CreateException ex ) 
{
	throw new ECSystemException(ECMessage._ERR_CREATE_EXCEPTION, this.getClass().getName(), methodName,
			ECMessageHelper.generateMsgParms( ex.getMessage()), ex );
}
catch( javax.naming.NamingException ex ) {
	throw new ECSystemException(ECMessage._ERR_GENERIC, this.getClass().getName(), methodName, 
			ECMessageHelper.generateMsgParms(ex.getMessage()), ex );
}
catch( java.rmi.RemoteException ex ) {
	throw new ECSystemException(ECMessage._ERR_REMOTE_EXCEPTION, this.getClass().getName(), methodName, 
			ECMessageHelper.generateMsgParms(ex.getMessage()), ex );
}
catch (FinderException ex) {
	ECMessageLog.out(ECMessage._ERR_LOAD_ORDERITEM_DATA, this.getClass().getName(), methodName); 
	return false;
}

return true;
}
/**
 * Get all the purchaser data for WCS Order Create message
 * @return boolean
 */
public boolean setOrderCreatePurchaserData() throws ECException {
final String methodName = "setOrderCreatePurchaserData";	
// Get all the purchaser data for WCS Order Create message from the appropriate tables
// Purchaser Data <HDR020>
try 
{
	String purchaserMemberID = orderNVP.getString(OrderCreateConstants.SHOPPER_REF_NUMBER);
	if (purchaserMemberID == OrderCreateConstants.NOT_AVAILABLE) return true;

	// Since ADDRESS table can contain multiple address entries for any given
	// memberID, the way to get a single address is to use the criteria
	// where logonID = nickname in the ADDRESS table.
				
	// Access the UserRegistry Access Bean and find the LogonID using memberID
	UserRegistryAccessBean uregab = new UserRegistryAccessBean();	
	uregab.setInitKey_UserId(purchaserMemberID);

	String logonId = null;
	if ((logonId=uregab.getLogonId()) != null)
		orderNVP.put(OrderCreateConstants.SHOPPER_LOGIN_ID, logonId);
		
	// Get single address entry from ADDRESS table using criteria logonID=nickname
	AddressAccessBean currAddressBean = addressBean.findByNickname(logonId, Long.valueOf(purchaserMemberID.toString()));

	String tempString = null;
	if ((tempString=currAddressBean.getLastName()) != null)
		orderNVP.put(OrderCreateConstants.PURCHASER_LAST_NAME, tempString);
	if ((tempString=currAddressBean.getMiddleName()) != null)
		orderNVP.put(OrderCreateConstants.PURCHASER_MIDDLE_NAME, tempString);
	if ((tempString=currAddressBean.getFirstName()) != null)
		orderNVP.put(OrderCreateConstants.PURCHASER_FIRST_NAME, tempString);
	if ((tempString=currAddressBean.getAddress1()) != null)
		orderNVP.put(OrderCreateConstants.PURCHASER_ADDR1, tempString);
	if ((tempString=currAddressBean.getAddress2()) != null)
		orderNVP.put(OrderCreateConstants.PURCHASER_ADDR2, tempString);
	if ((tempString=currAddressBean.getAddress3()) != null)
		orderNVP.put(OrderCreateConstants.PURCHASER_ADDR3, tempString);
	if ((tempString=currAddressBean.getCity()) != null)
		orderNVP.put(OrderCreateConstants.PURCHASER_CITY, tempString);
	if ((tempString=currAddressBean.getState()) != null)
		orderNVP.put(OrderCreateConstants.PURCHASER_STATE, tempString);
	if ((tempString=currAddressBean.getCountry()) != null)
		orderNVP.put(OrderCreateConstants.PURCHASER_COUNTRY, tempString);
	if ((tempString=currAddressBean.getZipCode()) != null)
		orderNVP.put(OrderCreateConstants.PURCHASER_ZIPCODE, tempString);
	if ((tempString=currAddressBean.getEmail1()) != null)
		orderNVP.put(OrderCreateConstants.PURCHASER_EMAIL1, tempString);
	if ((tempString=currAddressBean.getEmail2()) != null)
		orderNVP.put(OrderCreateConstants.PURCHASER_EMAIL2, tempString);
	if ((tempString=currAddressBean.getPhone1()) != null)
		orderNVP.put(OrderCreateConstants.PURCHASER_PHONE1, tempString);
	if ((tempString=currAddressBean.getPhone2()) != null)
		orderNVP.put(OrderCreateConstants.PURCHASER_PHONE2, tempString);

	if ((tempString=currAddressBean.getFax1()) != null)
		orderNVP.put(OrderCreateConstants.PURCHASER_FAX, tempString);
	else if ((tempString=currAddressBean.getFax2()) != null)
		orderNVP.put(OrderCreateConstants.PURCHASER_FAX, tempString);

	if ((tempString=currAddressBean.getOrganizationUnitName()) != null)
		orderNVP.put(OrderCreateConstants.PURCHASER_COMPANY_NAME, tempString);
	else if ((tempString=currAddressBean.getOrganizationName()) != null)
		orderNVP.put(OrderCreateConstants.PURCHASER_COMPANY_NAME, tempString);

	currAddressBean.commitCopyHelper();
/*		
	// To get the Shooper Group Name, first get the MBRGRP_ID from the
	// MBRGRPMBR table using MEMBER_ID as the search key.	
	MemberGroupMemberAccessBean mgmab = new MemberGroupMemberAccessBean();	
	mgmab.setInitKey_MemberId(purchaserMemberID);

	String memberGroupID;
	memberGroupID = mgmab.getMbrGrpId();

	// Using the newly found MBRGRP_ID, use it as the search key to get
	// the NAME from MBRGRP table. 
	MemberGroupAccessBean mgab = new MemberGroupAccessBean();	
	mgab.setInitKey_nMemberReferenceNumber(memberGroupID);

	if ((tempString=mgab.getName()) != null)
		orderNVP.put(OrderCreateConstants.PURCHASER_SHOPPER_GROUP_NAME, tempString);
*/
}
catch( javax.ejb.CreateException ex ) 
{
	throw new ECSystemException(ECMessage._ERR_CREATE_EXCEPTION, this.getClass().getName(), methodName,
			ECMessageHelper.generateMsgParms( ex.getMessage()), ex );
}
catch( javax.naming.NamingException ex ) {
	throw new ECSystemException(ECMessage._ERR_GENERIC, this.getClass().getName(), methodName, 
			ECMessageHelper.generateMsgParms(ex.getMessage()), ex );
}
catch( java.rmi.RemoteException ex ) {
	throw new ECSystemException(ECMessage._ERR_REMOTE_EXCEPTION, this.getClass().getName(), methodName, 
			ECMessageHelper.generateMsgParms(ex.getMessage()), ex );
}
catch (FinderException ex) {
	ECMessageLog.out(ECMessage._ERR_OC_PURCHASER_ERROR, this.getClass().getName(), methodName);
	return false;
}

return true;
}
/**
 * Get all the store data for WCS Order Create message
 * @return boolean
 */
public boolean setOrderCreateStoreData() throws ECException {
final String methodName = "setOrderCreateStoreData";	
// Get all the supplier/store data for WCS Order Create message from the appropriate tables
// Supplier/Store Data <HDR040>
try 
{
	String tempString;
	String orderStoreID = orderNVP.getString(OrderCreateConstants.ORDER_STORE_ID);
	if (orderStoreID == OrderCreateConstants.NOT_AVAILABLE) return true;

	StoreEntityDescriptionAccessBean storeEntDescBean = new StoreEntityDescriptionAccessBean();
	storeEntDescBean.setInitKey_storeEntityId(orderStoreID);
	storeEntDescBean.setInitKey_languageId(getCommandContext().getLanguageId().toString());

	Integer addressId = storeEntDescBean.getContactAddressIdInEJBType();
	
	if (addressId !=null)
	{	
		StoreAddressAccessBean storeAddressBean = new StoreAddressAccessBean();

		storeAddressBean.setInitKey_storeAddressId(storeEntDescBean.getContactAddressId());
		//SupplierName, Contact last, middle, first name and title should come from store

		if ((tempString=storeEntDescBean.getDisplayName()) != null)
	    	orderNVP.put(OrderCreateConstants.SUPPLIER_NAME, tempString);
		if ((tempString=storeAddressBean.getAddress1()) != null)
			orderNVP.put(OrderCreateConstants.SUPPLIER_ADDR1, tempString);
		if ((tempString=storeAddressBean.getAddress2()) != null)
			orderNVP.put(OrderCreateConstants.SUPPLIER_ADDR2, tempString);
		if ((tempString=storeAddressBean.getAddress3()) != null)
			orderNVP.put(OrderCreateConstants.SUPPLIER_ADDR3, tempString);
		if ((tempString=storeAddressBean.getCity()) != null)
			orderNVP.put(OrderCreateConstants.SUPPLIER_CITY, tempString);
		if ((tempString=storeAddressBean.getState()) != null)
			orderNVP.put(OrderCreateConstants.SUPPLIER_STATE, tempString);
		if ((tempString=storeAddressBean.getCountry()) != null)
			orderNVP.put(OrderCreateConstants.SUPPLIER_COUNTRY, tempString);
		if ((tempString=storeAddressBean.getZipCode()) != null)
			orderNVP.put(OrderCreateConstants.SUPPLIER_ZIPCODE, tempString);

		if ((tempString=storeAddressBean.getPhone1()) != null)
			orderNVP.put(OrderCreateConstants.SUPPLIER_PHONE1, tempString);
		else if ((tempString=storeAddressBean.getPhone2()) != null)
			orderNVP.put(OrderCreateConstants.SUPPLIER_PHONE1, tempString);

		if ((tempString=storeAddressBean.getLastName()) != null)
			orderNVP.put(OrderCreateConstants.SUPPLIER_CONTACT_LAST_NAME, tempString);
		if ((tempString=storeAddressBean.getMiddleName()) != null)
			orderNVP.put(OrderCreateConstants.SUPPLIER_CONTACT_MIDDLE_NAME, tempString);
		if ((tempString=storeAddressBean.getFirstName()) != null)
			orderNVP.put(OrderCreateConstants.SUPPLIER_CONTACT_FIRST_NAME, tempString);
		if ((tempString=storeAddressBean.getPersonTitle()) != null)
			orderNVP.put(OrderCreateConstants.SUPPLIER_CONTACT_TITLE, tempString);
		if ((tempString=storeAddressBean.getEmail1()) != null)
			orderNVP.put(OrderCreateConstants.SUPPLIER_CONTACT_EMAIL1, tempString);
		if ((tempString=storeAddressBean.getEmail2()) != null)
			orderNVP.put(OrderCreateConstants.SUPPLIER_CONTACT_EMAIL2, tempString);
		if ((tempString=storeAddressBean.getPhone1()) != null)
			orderNVP.put(OrderCreateConstants.SUPPLIER_CONTACT_PHONE1, tempString);
		if ((tempString=storeAddressBean.getPhone2()) != null)
			orderNVP.put(OrderCreateConstants.SUPPLIER_CONTACT_PHONE2, tempString);
	}	
	
	// 	Save the Store level default ship mode just incase needed by the
	//  setOrderCreateItemData() later on
	StoreDefaultAccessBean storeDefBean = new StoreDefaultAccessBean();
	storeDefBean.setInitKey_storeId(orderStoreID);
		
	if (storeDefBean.getShipModeIdInEJBType() != null)
		orderNVP.put(OrderCreateConstants.DEFAULT_STORE_SHIPMODE, storeDefBean.getShipModeId());
}
catch( javax.ejb.CreateException ex ) 
{
	throw new ECSystemException(ECMessage._ERR_CREATE_EXCEPTION, this.getClass().getName(), methodName,
			ECMessageHelper.generateMsgParms( ex.getMessage()), ex );
}
catch( javax.naming.NamingException ex ) {
	throw new ECSystemException(ECMessage._ERR_GENERIC, this.getClass().getName(), methodName, 
			ECMessageHelper.generateMsgParms(ex.getMessage()), ex );
}
catch( java.rmi.RemoteException ex ) {
	throw new ECSystemException(ECMessage._ERR_REMOTE_EXCEPTION, this.getClass().getName(), methodName, 
			ECMessageHelper.generateMsgParms(ex.getMessage()), ex );
}
catch (FinderException ex) {
	ECMessageLog.out(ECMessage._ERR_OC_SUPPLIER_ERROR, this.getClass().getName(), methodName);
	return false;
}

return true;
}
/**
 * Get all the name value pairs for the WCS Order Create message.
 * @return boolean
 */
public boolean setOrderNVPValues() {
	//Get all the order values for NC Order Create message from the appropriate tables
try 
{
	if (!setOrderCreateHeaderData()) return false;
	if (!setOrderCreatePurchaserData()) return false;
	if (!setOrderCreateBillToData()) return false;
	if (!setOrderCreateStoreData()) return false;
	if (!setOrderCreateItemData()) return false;	
}
catch (Exception ex)
{
	// Exception while doing one of the above, return false
	return false;
}	

return true;
}
/**
 * Sets the order reference number.
 */
public void setOrderRn(Long OrderRn)
	{
		orderRefNumber = OrderRn;
	}
/**
 * Set the request properties as input for the command.
 */
public void setRequestProperties(TypedProperty aRequestProperties) throws com.ibm.commerce.exception.ECApplicationException
{
		ECTrace.entry(ECTraceIdentifiers.COMPONENT_TRANSPORT_ADAPTER, this.getClass().getName(), "setRequestProperties");

		ocProp = aRequestProperties;

		// This is a Task Command, not a Controller Command.
		// The order ref number should be passed/set by the caller, ie.
		// the extendOrderProcess method in OrderProcess controller command.

		// orderRefNumber = requestProperties.getLong(ICIConstants.ICI_ORDER_REFNUM, null);
			
		ECTrace.exit(ECTraceIdentifiers.COMPONENT_TRANSPORT_ADAPTER, this.getClass().getName(), "setRequestProperties");
}
/**
 * Build the WCS Order Create message
 * @return boolean
 * @param aRequestProperty com.ibm.commerce.datatype.TypedProperty
 */
public boolean writeOrder() {
final String methodName = "writeOrder";
try {
	//Write NC OrderCreate Message into orderMsg field
	orderMsg = new String();
	orderMsg += "<ECEDOC><PROLOG>ON        01          </PROLOG><HEADER>";
	orderMsg += "<HDR010>01";
	orderMsg += pad(orderRefNumber.toString(),10);
	orderMsg += getField(orderNVP, OrderCreateConstants.ORDER_DATE,8) + 
				getField(orderNVP, OrderCreateConstants.ORDER_TIME,6);
	orderMsg += getField(orderNVP, OrderCreateConstants.CURRENCY_TYPE,10) + 
				getField(orderNVP, OrderCreateConstants.TOTAL_PRICE,16);
	orderMsg += getField(orderNVP, OrderCreateConstants.TOTAL_TAX_PRICE,16) + 
				getField(orderNVP, OrderCreateConstants.TOTAL_SHIPPING_PRICE,16);
	orderMsg += getField(orderNVP, OrderCreateConstants.TOTAL_TAX_SHIPPING_PRICE,16) + 
				getField(orderNVP, OrderCreateConstants.SHOPPER_REF_NUMBER,10);
	orderMsg += getField(orderNVP, OrderCreateConstants.MERCHANT_REF_NUMBER,10) + 
				getField(orderNVP, OrderCreateConstants.MERCHANT_ORDER_NUMBER,30);
	orderMsg += getField(orderNVP, OrderCreateConstants.BILLTO_REF_NUMBER,10) + 
				getField(orderNVP, OrderCreateConstants.ORDER_CUST_FIELD1,10);
	orderMsg += getField(orderNVP, OrderCreateConstants.ORDER_CUST_FIELD2,16) + 
				getField(orderNVP, OrderCreateConstants.ORDER_CUST_FIELD3,254);
	orderMsg += "</HDR010>";

	orderMsg += "<HDR020>01";
	orderMsg += getField(orderNVP, OrderCreateConstants.SHOPPER_LOGIN_ID, 31);
	orderMsg += getField(orderNVP, OrderCreateConstants.PURCHASER_LAST_NAME, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.PURCHASER_MIDDLE_NAME, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.PURCHASER_FIRST_NAME, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.PURCHASER_ADDR1, 50);
	orderMsg += getField(orderNVP, OrderCreateConstants.PURCHASER_ADDR2, 50);
	orderMsg += getField(orderNVP, OrderCreateConstants.PURCHASER_ADDR3, 50);
	orderMsg += getField(orderNVP, OrderCreateConstants.PURCHASER_CITY, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.PURCHASER_STATE, 20);
	orderMsg += getField(orderNVP, OrderCreateConstants.PURCHASER_COUNTRY, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.PURCHASER_ZIPCODE, 20);
	orderMsg += getField(orderNVP, OrderCreateConstants.PURCHASER_EMAIL1, 254);
	orderMsg += getField(orderNVP, OrderCreateConstants.PURCHASER_EMAIL2, 254);
	orderMsg += getField(orderNVP, OrderCreateConstants.PURCHASER_PHONE1, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.PURCHASER_PHONE2, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.PURCHASER_FAX, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.PURCHASER_COMPANY_NAME, 80);
	orderMsg += getField(orderNVP, OrderCreateConstants.PURCHASER_SHOPPER_GROUP_NAME, 50);
	orderMsg += "</HDR020>";
		
	orderMsg += "<HDR030>01";
	orderMsg += getField(orderNVP, OrderCreateConstants.BILLTO_LAST_NAME, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.BILLTO_MIDDLE_NAME, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.BILLTO_FIRST_NAME, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.BILLTO_ADDR1, 50);
	orderMsg += getField(orderNVP, OrderCreateConstants.BILLTO_ADDR2, 50);
	orderMsg += getField(orderNVP, OrderCreateConstants.BILLTO_ADDR3, 50);
	orderMsg += getField(orderNVP, OrderCreateConstants.BILLTO_CITY, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.BILLTO_STATE, 20);
	orderMsg += getField(orderNVP, OrderCreateConstants.BILLTO_COUNTRY, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.BILLTO_ZIPCODE, 20);
	orderMsg += getField(orderNVP, OrderCreateConstants.BILLTO_EMAIL1, 254);
	orderMsg += getField(orderNVP, OrderCreateConstants.BILLTO_EMAIL2, 254);
	orderMsg += getField(orderNVP, OrderCreateConstants.BILLTO_PHONE1, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.BILLTO_PHONE2, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.BILLTO_FAX, 30);
	orderMsg += "</HDR030>";

	orderMsg += "<HDR040>01";	
	orderMsg += getField(orderNVP, OrderCreateConstants.SUPPLIER_NAME, 80);
	orderMsg += getField(orderNVP, OrderCreateConstants.SUPPLIER_ADDR1, 50);
	orderMsg += getField(orderNVP, OrderCreateConstants.SUPPLIER_ADDR2, 50);
	orderMsg += getField(orderNVP, OrderCreateConstants.SUPPLIER_ADDR3, 50);
	orderMsg += getField(orderNVP, OrderCreateConstants.SUPPLIER_CITY, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.SUPPLIER_STATE, 20);
	orderMsg += getField(orderNVP, OrderCreateConstants.SUPPLIER_COUNTRY, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.SUPPLIER_ZIPCODE, 20);
	orderMsg += getField(orderNVP, OrderCreateConstants.SUPPLIER_PHONE1, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.SUPPLIER_CONTACT_LAST_NAME, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.SUPPLIER_CONTACT_MIDDLE_NAME, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.SUPPLIER_CONTACT_FIRST_NAME, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.SUPPLIER_CONTACT_TITLE, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.SUPPLIER_CONTACT_PHONE1, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.SUPPLIER_CONTACT_PHONE2, 30);
	orderMsg += getField(orderNVP, OrderCreateConstants.SUPPLIER_CONTACT_EMAIL1, 254);
	orderMsg += getField(orderNVP, OrderCreateConstants.SUPPLIER_CONTACT_EMAIL2, 254);
	orderMsg += "</HDR040>";

	//Get and print USRLST data
	String HDRUserList = getHeaderExtensionRecords();
	if (HDRUserList != null)
		orderMsg += "<USRLST>" + HDRUserList + "</USRLST>";
	orderMsg += "</HEADER>";
	
	//items
	Vector itemsVector = (Vector) orderNVP.get("ItemsVector");
	TypedProperty currItemProperty;
	if (itemsVector == null) return false;
	orderMsg += "<ITMLST>";
	int	numberOfItems = itemsVector.size();
	for (int i=0;i<numberOfItems;i++) {
		currItemProperty = (TypedProperty) itemsVector.elementAt(i);
		orderMsg += "<ITMDAT>";
		orderMsg += "<ITM010>01";
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_LINE_NUMBER, 3);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_REF_NUMBER,10);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_PRODUCT_REF_NUMBER,10);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_PRODUCT_NUMBER,64);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_PRODUCT_SHORT_DESCRIPTION,254);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_UNIT_PRICE,16);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_CURRENCY_TYPE,10);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_PRODUCT_QUANTITY,10);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_SHIPTO_ADDR_REF_NUMBER,10);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_SHIPMODE_REF_NUMBER,10);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_STATUS,1);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_SHIPTO_LAST_NAME,30);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_SHIPTO_MIDDLE_NAME,30);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_SHIPTO_FIRST_NAME,30);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_SHIPTO_ADDR1,50);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_SHIPTO_ADDR2,50);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_SHIPTO_ADDR3,50);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_SHIPTO_CITY,30);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_SHIPTO_STATE,20);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_SHIPTO_COUNTRY,30);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_SHIPTO_ZIPCODE,20);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_SHIPTO_EMAIL1,254);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_SHIPTO_EMAIL2,254);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_SHIPTO_PHONE1,30);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_SHIPTO_PHONE2,30);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_SHIPTO_FAX,30);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_SHIPPING_CARRIER,30);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_SHIPPING_METHOD,30);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_SHIPTO_COMMENT,254);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_CREATION_TIMESTAMP,64);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_UPDATE_TIMESTAMP,64);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_CUST_FIELD1,10);
		orderMsg += getField(currItemProperty, OrderCreateConstants.ITEM_CUST_FIELD2,254);
		orderMsg += "</ITM010>";
		//Get and print USRLST data
		String ITMUserList = getItemExtensionRecords();
		if (ITMUserList != null)
			orderMsg += "<USRLST>" + ITMUserList + "</USRLST>";
		orderMsg += "</ITMDAT>";

	}
	orderMsg += "</ITMLST>";
	orderMsg += "</ECEDOC>";
	
}
catch (Exception ex)
{
	ECMessageLog.out(ECMessage._ERR_OC_WRITE_ORDER_ERROR, this.getClass().getName(), methodName);
	return false;
}	
return true;
}
}
