//********************************************************************
//*-------------------------------------------------------------------
//* Sample Source
//*
//* 5724-A18
//*
//* (c) Copyright IBM Corp. 2000, 2002
//*
//* The source code for this program is not published or otherwise
//* divested of its trade secrets, irrespective of what has been
//* deposited with the US Copyright Office.
//*-------------------------------------------------------------------
//*
////////////////////////////////////////////////////////////////////////////////

import com.ibm.commerce.usermanagement.commands.*;

import java.util.*;
import com.ibm.commerce.ras.*;
import com.ibm.commerce.exception.*;
import com.ibm.commerce.server.*;
import com.ibm.commerce.common.objects.*; 
import com.ibm.commerce.command.*;
import com.ibm.commerce.server.*;
import com.ibm.commerce.datatype.*;
/**
 * The base class for AuditAddressCmdImpl, AuditUserRegistrationCmdImpl and AuditOrgEntityCmdImpl.
 */
public class AuditBaseCmdImpl extends TaskCommandImpl implements AuditBaseCmd
{
	public static final String COPYRIGHT = com.ibm.commerce.copyright.IBMCopyright.SHORT_COPYRIGHT;
	public final static String CLASSNAME = "com.ibm.commerce.usermanagement.commands.AuditBaseCmdImpl";		
	/* A indicator indicates whether or not the audit is passed
	 *    - True audit is passed
	 *    - True audit is not passed
	 */
	protected boolean ibResult = true;
	protected TypedProperty requestProperties = null;
	protected String istrPropertyFileName = null;
	protected String istrStoreDirectory = null;	
	protected String istrErrorViewName = null;
	protected Hashtable ihshProperties = null;
	protected SortedMap ismpProperties = null;
	protected String istrPathSeparator = "/";	
/**
 * Return the audit result.
 */
public boolean getAuditResult() {
	return ibResult;
}
private String getFullPropertyFilePath(String astrPropertyFileName, String astrStoreDirectory)
{
	final String METHODNAME = "getFullPropertyFilePath";
	ECTrace.entry(ECTraceIdentifiers.COMPONENT_USER, CLASSNAME, METHODNAME);
	
	String strFullPropertyFilePath = null;
	if (astrPropertyFileName != null)
		astrPropertyFileName = astrPropertyFileName.trim();
	
	if (astrStoreDirectory != null && astrStoreDirectory.trim().length() > 0)
	{
		astrStoreDirectory = astrStoreDirectory.trim();
		strFullPropertyFilePath = astrStoreDirectory + istrPathSeparator + astrPropertyFileName;
	}
	else
	{
		strFullPropertyFilePath = astrPropertyFileName;
	}
	ECTrace.trace(ECTraceIdentifiers.COMPONENT_USER, CLASSNAME, METHODNAME,
		"Get full property file name:" + strFullPropertyFilePath);
	
	ECTrace.exit(ECTraceIdentifiers.COMPONENT_USER, CLASSNAME, METHODNAME);	
	return strFullPropertyFilePath;
}
/**
 * Gets the path separator. path separator is used to separate the store directory
 * and the property file name. For example:
 * <PRE>
 * "store1/UserRegistration"
 * </PRE>
 * "/" is the path separator.<BR>
 *
 * @return The path separator
 */
public String getPathSeparator()
{
	return istrPathSeparator;
}
/**
 * Gets the name of property file
 * 
 * @return The name of the property file
 */
public String getPropertyFileName()
{
	return istrPropertyFileName;
}
/**
 * Gets the name of the store directory, which is used for finding property files
 * belong to this store.
 * 
 * @return The name of the store directory
 */
public String getStoreDirectory()
{
	return istrStoreDirectory;
}
public void performExecute() throws ECException
{
	//Define the name of this method
	final String METHODNAME = "performExecute";
	ECTrace.entry(ECTraceIdentifiers.COMPONENT_USER, CLASSNAME, METHODNAME);
	TypedProperty hshNVPs = new TypedProperty();	
	super.performExecute();
	
	if (getStoreDirectory() == null)
	{
		try
		{
			StoreAccessBean abStore = commandContext.getStore();
			if (abStore != null)
			{
				istrStoreDirectory = abStore.getDirectory();
				ECTrace.trace(ECTraceIdentifiers.COMPONENT_USER, CLASSNAME, METHODNAME,
				"Get store directory:" + istrStoreDirectory);
				
			}
		}
		catch(Exception e)
		{
			ECTrace.trace(ECTraceIdentifiers.COMPONENT_USER, CLASSNAME, METHODNAME,
				"Can not getting store directory information" + e.toString());
			istrStoreDirectory = "";			
		}
	}
	try
	{
		ismpProperties = PropertyResourceBundleReader.readSortedProperties(getFullPropertyFilePath(getPropertyFileName(), getStoreDirectory()), commandContext.getLocale());
		if (ismpProperties != null)
		{
			Iterator entryIterator = ismpProperties.entrySet().iterator();
			while (entryIterator.hasNext())
			{
				Map.Entry entry = (Map.Entry) entryIterator.next();
				Hashtable hshField = (Hashtable) entry.getValue();
				if (hshField.containsKey(ECUserConstants.EC_RB_REQUIRED) && ((Boolean)hshField.get(ECUserConstants.EC_RB_REQUIRED)).booleanValue())
				{
					String strFieldName = (String) hshField.get(ECUserConstants.EC_RB_NAME);
					if (strFieldName != null && requestProperties.containsKey(strFieldName))
					{
						String strFieldValue = requestProperties.getString(strFieldName, null);
						
						if (strFieldValue != null && strFieldValue.length() == 0)
						{
							ibResult = false;
							if (strFieldName.equals(ECUserConstants.EC_ADDR_LASTNAME))
								hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_LASTNAME);
							if (strFieldName.equals(ECUserConstants.EC_ADDR_FIRSTNAME))					
								hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_FIRSTNAME);
							if (strFieldName.equals(ECUserConstants.EC_ADDR_ADDRESS1))									
								hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_ADDRESS1);
							if (strFieldName.equals(ECUserConstants.EC_ADDR_CITY))					
								hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_CITY);
							if (strFieldName.equals(ECUserConstants.EC_ADDR_STATE))					
								hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_STATE);
							if (strFieldName.equals(ECUserConstants.EC_ADDR_ZIPCODE))									
								hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_ZIPCODE);
							if (strFieldName.equals(ECUserConstants.EC_ADDR_COUNTRY))									
								hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_COUNTRY);

							if (strFieldName.equals(ECUserConstants.EC_ADDR_EMAIL1))									
								hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_EMAIL1);				
							if (strFieldName.equals(ECUserConstants.EC_ADDR_EMAIL2))									
								hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_EMAIL2);				
							if (strFieldName.equals(ECUserConstants.EC_ADDR_PHONE1))									
								hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_PHONE1);				
							if (strFieldName.equals(ECUserConstants.EC_ADDR_PHONE2))									
								hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_PHONE2);				
							if (strFieldName.equals(ECUserConstants.EC_ADDR_FAX1))									
								hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_FAX1);				
							if (strFieldName.equals(ECUserConstants.EC_ADDR_FAX2))									
								hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_FAX2);				

							if (strFieldName.equals(ECUserConstants.EC_BPROF_EMPLOYEEID))									
								hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_BPROF_ERR_BAD_EMPLOYEEID);				
									
							throw new ECApplicationException(ECMessage._ERR_CMD_INVALID_PARAM, CLASSNAME, METHODNAME,
										ECMessageHelper.generateMsgParms(strFieldName),
										istrErrorViewName, hshNVPs);
						}
					}
				}
			}	
		}
		else
		{
			ihshProperties = PropertyResourceBundleReader.readProperties(getFullPropertyFilePath(getPropertyFileName(), getStoreDirectory()), commandContext.getLocale());	
			if (ihshProperties != null)
			{
				Enumeration enmFields = ihshProperties.keys();
				while (enmFields.hasMoreElements())
				{
					String strFieldName = (String)enmFields.nextElement();
					Hashtable hshField = (Hashtable)ihshProperties.get(strFieldName);
				
					if (hshField.containsKey(ECUserConstants.EC_RB_REQUIRED) && ((Boolean)hshField.get(ECUserConstants.EC_RB_REQUIRED)).booleanValue())
					{
						if (requestProperties.containsKey(strFieldName))
						{
							String strFieldValue = requestProperties.getString(strFieldName, null);
						
							if (strFieldValue != null && strFieldValue.length() == 0)
							{
								ibResult = false;
								if (strFieldName.equals(ECUserConstants.EC_ADDR_LASTNAME))
									hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_LASTNAME);
								if (strFieldName.equals(ECUserConstants.EC_ADDR_FIRSTNAME))					
									hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_FIRSTNAME);
								if (strFieldName.equals(ECUserConstants.EC_ADDR_ADDRESS1))									
									hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_ADDRESS1);
								if (strFieldName.equals(ECUserConstants.EC_ADDR_CITY))					
									hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_CITY);
								if (strFieldName.equals(ECUserConstants.EC_ADDR_STATE))					
									hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_STATE);
								if (strFieldName.equals(ECUserConstants.EC_ADDR_ZIPCODE))									
									hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_ZIPCODE);
								if (strFieldName.equals(ECUserConstants.EC_ADDR_COUNTRY))									
									hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_COUNTRY);

								if (strFieldName.equals(ECUserConstants.EC_ADDR_EMAIL1))									
									hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_EMAIL1);				
								if (strFieldName.equals(ECUserConstants.EC_ADDR_EMAIL2))									
									hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_EMAIL2);				
								if (strFieldName.equals(ECUserConstants.EC_ADDR_PHONE1))									
									hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_PHONE1);				
								if (strFieldName.equals(ECUserConstants.EC_ADDR_PHONE2))									
									hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_PHONE2);				
								if (strFieldName.equals(ECUserConstants.EC_ADDR_FAX1))									
									hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_FAX1);				
								if (strFieldName.equals(ECUserConstants.EC_ADDR_FAX2))									
									hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_ADDR_ERR_BAD_FAX2);				

								if (strFieldName.equals(ECUserConstants.EC_BPROF_EMPLOYEEID))									
									hshNVPs.put(ECConstants.EC_ERROR_CODE, ECUserConstants.EC_BPROF_ERR_BAD_EMPLOYEEID);				
									
								throw new ECApplicationException(ECMessage._ERR_CMD_INVALID_PARAM, CLASSNAME, METHODNAME,
										ECMessageHelper.generateMsgParms(strFieldName),
										istrErrorViewName, hshNVPs);
							}
						}
					}
				}
			}
		}
	}
	catch(Exception e)
	{
		if (e instanceof ECApplicationException)
			throw (ECApplicationException)e;
		else
			ECTrace.trace(ECTraceIdentifiers.COMPONENT_USER, CLASSNAME, METHODNAME, 
					"Exception thrown when read from property file '" + getPropertyFileName() + "': " + e.toString());
	}
		
	ibResult = true;
		
	ECTrace.exit(ECTraceIdentifiers.COMPONENT_USER, CLASSNAME, METHODNAME);
}
/**
 */
public void setErrorViewName(String astrErrorViewName)
{
	istrErrorViewName = astrErrorViewName;
}
/**
 * Sets the path separator. path separator is used to separate the store directory
 * and the property file name. For example:
 * <PRE>
 * "store1/UserRegistration"
 * </PRE>
 * "/" is the path separator.<BR>
 * If path separator is not set, the databean will use the default one: "/" (working 
 * under Windows platform).
 *
 * @param astrPathSeparator The path separator
 */
public void setPathSeparator(String astrPathSeparator)
{
	if (astrPathSeparator != null)
		istrPathSeparator = astrPathSeparator.trim();
}
/**
 */
public void setPropertyFileName(String astrPropertyFileName)
{
	istrPropertyFileName = astrPropertyFileName;
}
public void setRequestProperties(TypedProperty aRequestProperties) throws ECApplicationException {
	ECTrace.entry(ECTraceIdentifiers.COMPONENT_ORDER, this.getClass().getName(), "setRequestProperties");
	requestProperties = aRequestProperties;
	// Read Properties from property file.
	

	ECTrace.exit(ECTraceIdentifiers.COMPONENT_ORDER, this.getClass().getName(), "setRequestProperties");
}
/**
 * Sets the name of store directory, which is used as the path to the find the 
 * property file. 
 * For example, if property files of a store is under the directory "store31" and
 * the parent directory of "store31" directory is included in the class path, 
 * then this method should be called to set StoreDirectory to "store31".
 * If the store directory is not set, ResourceBundleDataBean will try to get it 
 * from commandContext.
 *
 * @param astrStoreDirectory The name of store directory
 */
public void setStoreDirectory(String astrStoreDirectory)
{
	if (astrStoreDirectory != null)
		istrStoreDirectory = astrStoreDirectory.trim();
}
}
